==> kom%2B%2B-0.5.tar.gz: kom++-0.5/libconnection/create_anonymous_text_q.h <==
// Create an anonymous text.
//
// $Id: create_anonymous_text_q.h,v 1.7 1995/11/14 00:35:00 ceder Exp $
// Copyright (C) 1994  Per Cederqvist and Inge Wallin
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

#ifndef KOMXX_CREATE_ANONYMOUS_TEXT_Q_H
#define KOMXX_CREATE_ANONYMOUS_TEXT_Q_H

#include <DLList.h>
#include "kom-types.h"
#include "question.h"
#include "recipient.h"

class Connection;
class LyStr;

// 59

class create_anonymous_text_question : public question {
  public:
    create_anonymous_text_question(Connection *conn, const LyStr &message, 
				   const DLList<Recipient> &recipients,
				   const DLList<Text_no>   &comment_to,
				   const DLList<Text_no>   &footnote_to);
    ~create_anonymous_text_question();
    void parser(prot_a_LyStr &str);
    Text_no result();
  private:
    Text_no anon_text;
};

#endif

==> kom%2B%2B-0.7.post.4.tar.gz: kom++-0.7.post.4/libconnection/create_anonymous_text_q.h <==
// Create an anonymous text.
//
// $Id: create_anonymous_text_q.h,v 1.8 1999/11/11 23:47:43 ceder Exp $
// Copyright (C) 1994  Per Cederqvist and Inge Wallin
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

#ifndef KOMXX_CREATE_ANONYMOUS_TEXT_Q_H
#define KOMXX_CREATE_ANONYMOUS_TEXT_Q_H

#include <vector>

#include "kom-types.h"
#include "question.h"
#include "recipient.h"

class Connection;
class LyStr;

// 59

class create_anonymous_text_question : public question {
  public:
    create_anonymous_text_question(Connection *conn, const LyStr &message, 
				   const vector<Recipient> &recipients,
				   const vector<Text_no>   &comment_to,
				   const vector<Text_no>   &footnote_to);
    ~create_anonymous_text_question();
    void parser(prot_a_LyStr &str);
    Text_no result();
  private:
    Text_no anon_text;
};

#endif
